@@ -352,7 +352,8 @@ get_ticket_sync (GoaKerberosProvider *self,
     }
 
   ret = TRUE;
-out:
+
+ out:
   g_clear_object (&account);
   g_clear_object (&ticketing);
   g_free (object_path);
@@ -1438,7 +1439,7 @@ ensure_credentials_sync (GoaProvider    *provider,
   g_date_time_unref (now);
   g_date_time_unref (expiration_time);
 
-out:
+ out:
   g_clear_object (&account);
   g_clear_object (&identity);
   g_mutex_unlock (&identity_manager_mutex);
@@ -1567,7 +1568,7 @@ sign_in_identity_sync (GoaKerberosProvider  *self,
 {
   GcrSecretExchange  *secret_exchange;
   char               *secret_key;
-  char               *return_key;
+  char               *return_key = NULL;
   char               *concealed_secret;
   char               *identity_object_path = NULL;
   gboolean            keys_exchanged;
@@ -1620,7 +1621,8 @@ sign_in_identity_sync (GoaKerberosProvider  *self,
                                                   error);
   g_mutex_unlock (&identity_manager_mutex);
 
-out:
+ out:
+  g_free (return_key);
   g_object_unref (secret_exchange);
   return identity_object_path;
 }
@@ -1642,7 +1644,6 @@ sign_in_thread (GSimpleAsyncResult  *result,
 
   error = NULL;
   object_path = sign_in_identity_sync (self, identifier, password, preauth_source, cancellable, &error);
-
   if (object_path == NULL)
     g_simple_async_result_take_error (result, error);
   else
